@@ -31,7 +31,7 @@
 */
 
 static char version[] =
-"mii-diag.c:v2.09 9/06/2003 Donald Becker (becker@scyld.com)\n"
+"mii-diag.c:v2.11 3/21/2005 Donald Becker (becker@scyld.com)\n"
 " http://www.scyld.com/diag/index.html\n";
 
 static const char usage_msg[] =
@@ -94,8 +94,9 @@ static const char long_usage_msg[] =
 #include <linux/if_ether.h>
 #endif
 
-typedef unsigned short u16;
-typedef unsigned int u32;
+typedef u_int32_t u32;
+typedef u_int16_t u16;
+typedef u_int8_t u8;
 
 #if defined(SIOCGPARAMS)  && SIOCGPARAMS != SIOCDEVPRIVATE+3
 #error Changed definition for SIOCGPARAMS
@@ -132,6 +133,9 @@ struct option longopts[] = {
 /* Usually in libmii.c, but trivial substitions are below. */
 extern int  show_mii_details(long ioaddr, int phy_id);
 extern void monitor_mii(long ioaddr, int phy_id);
+int  show_mii_details(long ioaddr, int phy_id) __attribute__((weak));
+void monitor_mii(long ioaddr, int phy_id) __attribute__((weak));
+
 
 /* Command-line flags. */
 unsigned int opt_a = 0,					/* Show-all-interfaces flag. */
@@ -607,11 +611,6 @@ static void monitor_status(long ioaddr, int phy_id)
 	}
 }
 
-/* These functions are not used if we are linked with libmii. */
-
-int  show_mii_details(long ioaddr, int phy_id) __attribute__((weak));
-void monitor_mii(long ioaddr, int phy_id) __attribute__((weak));
-
 int  show_mii_details(long ioaddr, int phy_id)
 {
 	int mii_reg, mii_val;
